(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    169547,       3978]
NotebookOptionsPosition[    167306,       3902]
NotebookOutlinePosition[    168597,       3947]
CellTagsIndexPosition[    168457,       3940]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Boucing Ball", "Section",
 CellChangeTimes->{{3.4196640361138463`*^9, 3.4196640361138463`*^9}, 
   3.4197043129716864`*^9},
 CellTags->"Bouncing ball"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`NDSolveProblems`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`NDSolveUtilities`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\"",
    "]"}], ";"}]}], "Input",
 CellTags->"Bouncing ball"],

Cell["\<\
This defines a function which computes the solution from one bounce to the \
next.  The solution is computed up until the next time the path intersects \
the ramp.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OneBounce", "[", 
    RowBox[{"k_", ",", " ", "ramp_"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{
    "t0_", ",", "x0_", ",", " ", "xp0_", ",", " ", "y0_", ",", " ", "yp0_"}], 
    "}"}], "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "sol", ",", " ", "t1", ",", " ", "x1", ",", " ", "xp1", ",", " ", "y1", 
      ",", " ", "yp1", ",", " ", "gramp", ",", " ", "gp"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"First", "[", 
       RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
            "0"}], ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"x", "'"}], "[", "t0", "]"}], "\[Equal]", " ", "xp0"}], 
           ",", " ", 
           RowBox[{
            RowBox[{"x", "[", "t0", "]"}], " ", "\[Equal]", " ", "x0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "''"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
            RowBox[{"-", "9.8"}]}], " ", ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "'"}], "[", "t0", "]"}], " ", "\[Equal]", " ", 
            "yp0"}], ",", " ", 
           RowBox[{
            RowBox[{"y", "[", "t0", "]"}], " ", "\[Equal]", " ", "y0"}]}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", "t0", ",", " ", "\[Infinity]"}], "}"}], ",", " ", 
         
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<EventLocator\>\"", ",", " ", 
            RowBox[{"\"\<Event\>\"", "\[RuleDelayed]", " ", 
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
              RowBox[{"ramp", "[", 
               RowBox[{"x", "[", "t", "]"}], "]"}]}]}]}], "}"}]}], ",", 
         RowBox[{"MaxStepSize", "\[Rule]", "0.01"}], ",", 
         RowBox[{"MaxSteps", "\[Rule]", " ", "20000"}]}], "]"}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"t1", " ", "=", " ", 
      RowBox[{
       RowBox[{"InterpolatingFunctionDomain", "[", 
        RowBox[{"x", " ", "/.", " ", "sol"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1", ",", "xp1", ",", "y1", ",", " ", "yp1"}], "}"}], " ", 
      "=", " ", 
      RowBox[{
       RowBox[{"Reflection", "[", 
        RowBox[{"k", ",", " ", "ramp"}], "]"}], "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t1", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"x", "'"}], "[", "t1", "]"}], ",", " ", 
          RowBox[{"y", "[", "t1", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"y", "'"}], "[", "t1", "]"}]}], "}"}], " ", "/.", " ", 
        "sol"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], " ", "/.", "sol"}], ",", 
         RowBox[{
         "t0", " ", "\[LessEqual]", " ", "t", " ", "\[LessEqual]", "  ", 
          "t1"}]}], "}"}], ",", " ", "\"\<X\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], " ", "/.", " ", "sol"}], ",", 
         RowBox[{
         "t0", " ", "\[LessEqual]", "  ", "t", " ", "\[LessEqual]", "  ", 
          "t1"}]}], "}"}], ",", " ", "\"\<Y\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1", ",", "y1"}], "}"}], ",", " ", "\"\<Bounces\>\""}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t1", ",", " ", "x1", ",", "xp1", ",", "y1", ",", " ", "yp1"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.384506306418277*^9, 3.384506315717894*^9}},
 CellTags->"Bouncing ball"],

Cell["\<\
This defines the function for the bounce when the ball hits the ramp. The \
formula is based on reflection about the normal to the ramp assuming only the \
fraction k of energy is left after a bounce.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Reflection", "[", 
    RowBox[{"k_", ",", " ", "ramp_"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", " ", "xp_", ",", " ", "y_", ",", " ", "yp_"}], "}"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gramp", ",", " ", "gp", ",", " ", "xpnew", ",", " ", "ypnew"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gramp", " ", "=", " ", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"ramp", "'"}], "[", "x", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{"NumberQ", "[", "gramp", "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Could not compute derivative \>\"", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gramp", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"ramp", "'"}], "[", "x", "]"}]}], ",", " ", "1"}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"gramp", ".", 
         RowBox[{"{", 
          RowBox[{"xp", ",", "yp"}], "}"}]}], " ", "\[Equal]", " ", "0"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<No reflection\>\"", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gp", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}], " ", 
       RowBox[{"Reverse", "[", "gramp", "]"}]}]}], ";", "\[IndentingNewLine]",
      
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xpnew", ",", " ", "ypnew"}], "}"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", 
         RowBox[{"(", 
          RowBox[{"gramp", ".", "gramp"}], ")"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"gp", " ", 
          RowBox[{"gp", ".", 
           RowBox[{"{", 
            RowBox[{"xp", ",", "yp"}], "}"}]}]}], " ", "-", " ", 
         RowBox[{"gramp", " ", 
          RowBox[{"gramp", ".", 
           RowBox[{"{", 
            RowBox[{"xp", ",", " ", "yp"}], "}"}]}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "xpnew", ",", " ", "y", ",", " ", "ypnew"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellTags->"Bouncing ball"],

Cell["\<\
This defines the function which runs the bouncing ball simulation for a given \
reflection ratio, ramp, and starting position.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{"Clear", "[", "wavyramp", "]"}]], "Input",
 CellChangeTimes->{{3.384504594217244*^9, 3.384504599739366*^9}},
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BouncingBall", "[", 
   RowBox[{"k_", ",", " ", "ramp_", ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"DynamicModule", "[", 
   RowBox[{
    RowBox[{"{", "data", "}"}], ",", 
    RowBox[{"Animate", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"ramp", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xmin", ",", " ", "xmax"}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"xmin", ",", " ", "xmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", ".025"}], ",", " ", "ymax"}], "}"}]}], 
             "}"}]}], ",", " ", 
           RowBox[{"AspectRatio", "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ymax", " ", "-", " ", "ymin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"xmax", " ", "-", " ", "xmin"}], ")"}]}]}], ",", 
           RowBox[{"Filling", "\[Rule]", " ", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", " ", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", " ", 
            RowBox[{"8", " ", "72"}]}]}], "]"}], ",", 
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Piecewise", "[", 
               RowBox[{"\"\<X\>\"", " ", "/.", "data"}], "]"}], ",", " ", 
              RowBox[{"Piecewise", "[", 
               RowBox[{"\"\<Y\>\"", " ", "/.", " ", "data"}], "]"}]}], "}"}], 
            "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "tt"}], "}"}], ",", " ", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", ".025", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Piecewise", "[", 
                  RowBox[{"\"\<X\>\"", " ", "/.", "data"}], "]"}], ",", " ", 
                 RowBox[{"Piecewise", "[", 
                  RowBox[{"\"\<Y\>\"", " ", "/.", " ", "data"}], "]"}]}], 
                "}"}], "/.", 
               RowBox[{"t", "\[Rule]", " ", "tt"}]}], ")"}], "]"}]}], "}"}], 
          "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tt", ",", "0.001", ",", "\"\<time\>\""}], "}"}], ",", 
        "0.001", ",", "2.67"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"SaveDefinitions", "\[Rule]", " ", "True"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Initialization", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"data", " ", "=", 
          RowBox[{"Reap", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Catch", "[", 
             RowBox[{
              RowBox[{"Sow", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x0", ",", "y0"}], "}"}], ",", " ", 
                "\"\<Bounces\>\""}], "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"NestWhile", "[", 
               RowBox[{
                RowBox[{"OneBounce", "[", 
                 RowBox[{"k", ",", " ", "ramp"}], "]"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "x0", ",", "0", ",", "y0", ",", "0"}], 
                 "}"}], ",", " ", 
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"1", " ", "-", " ", 
                   RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], " ", ">", " ", 
                  "0.01"}], "]"}], ",", " ", "2", ",", " ", "25"}], "]"}]}], 
             "]"}], ",", "_", ",", " ", "Rule"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"data", " ", "=", " ", 
          RowBox[{"Last", "[", "data", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"bounces", " ", "=", " ", 
          RowBox[{"(", 
           RowBox[{"\"\<Bounces\>\"", " ", "/.", " ", "data"}], ")"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xmax", " ", "=", " ", 
          RowBox[{"Max", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xmin", " ", "=", " ", 
          RowBox[{"Min", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymax", " ", "=", " ", 
          RowBox[{"Max", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymin", " ", "=", " ", 
          RowBox[{"Min", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"wavyramp", "[", "x_", "]"}], " ", ":=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", "<", "1"}], ",", 
            RowBox[{"1", "-", "x", "+", "  ", 
             RowBox[{".06", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"8.5", "Pi", " ", "x"}], "]"}]}]}], ",", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x", "-", "1"}], ")"}], "2"], "/", "4"}]}], "]"}]}], 
         ";"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"BouncingBall", "[", 
  RowBox[{".75", ",", " ", "wavyramp", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.249"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.382378761433864*^9, 3.382432206053246*^9, 3.384504090415389*^9, {
   3.384505716396228*^9, 3.384505787577943*^9}, 3.384505953259865*^9, {
   3.384506468292623*^9, 3.384506468525485*^9}},
 CellTags->"Bouncing ball"]
}, Closed]],

Cell[CellGroupData[{

Cell["\:5bfc\:6570\:6982\:5ff5\:7684\:8bfe\:4ef6", "Section",
 CellChangeTimes->{{3.419704162765701*^9, 3.4197041735011377`*^9}},
 CellTags->"Deviation"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"x0", "<", "#"}], ",", 
        RowBox[{"x0", "=", "#"}]}], "]"}], "&"}], "[", 
     RowBox[{"Switch", "[", 
      RowBox[{"func", ",", "p2", ",", 
       RowBox[{"-", "1.1"}], ",", "p3", ",", 
       RowBox[{"-", "1.17"}], ",", "p4", ",", 
       RowBox[{"-", "2.8"}], ",", "expf", ",", ".02", ",", "logisticf", ",", 
       "0.01"}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"x0", ">", "#"}], ",", 
        RowBox[{"x0", "=", "#"}]}], "]"}], "&"}], "[", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "func", ",", "p2", ",", "4.9", ",", "p3", ",", "3.9", ",", "p4", ",", 
       "2.8", ",", "expf", ",", "8.8", ",", "logisticf", ",", "7"}], "]"}], 
     "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"x1", "=", 
     RowBox[{"x0", " ", "+", " ", "deltax"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Switch", "[", 
     RowBox[{"func", ",", "\[IndentingNewLine]", "p2", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "xstart", ",", " ", "xstop", ",", "ystart", ",", "ystop", ",", "  ", 
          "kchangesides", ",", 
          RowBox[{"{", 
           RowBox[{"koffsetleft", ",", "koffsetright"}], "}"}], ",", 
          "deltaxpos", ",", "xyinset"}], "}"}], " ", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "6.1", ",", 
          RowBox[{"-", "1"}], ",", "11", ",", 
          RowBox[{"-", "0.9"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.6", ",", 
            RowBox[{"-", "0.6"}]}], "}"}], ",", 
          RowBox[{"-", "0.45"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.5", ",", "10"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"f", " ", "=", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"4", "x"}], "+", "5"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "p3", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "xstart", ",", " ", "xstop", ",", "ystart", ",", "ystop", ",", "  ", 
          "kchangesides", ",", 
          RowBox[{"{", 
           RowBox[{"koffsetleft", ",", "koffsetright"}], "}"}], ",", 
          "deltaxpos", ",", "xyinset"}], "}"}], " ", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "5", ",", 
          RowBox[{"-", "5"}], ",", "21", ",", 
          RowBox[{"-", "0.95"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.", ",", 
            RowBox[{"-", "0.5"}]}], "}"}], ",", 
          RowBox[{"-", "0.85"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "18"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"f", " ", "=", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           SuperscriptBox["x", "3"], " ", "-", 
           RowBox[{"6", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"5", " ", "x"}], "+", "12"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "p4", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "xstart", ",", " ", "xstop", ",", "ystart", ",", "ystop", ",", " ", 
          "kchangesides", ",", 
          RowBox[{"{", 
           RowBox[{"koffsetleft", ",", "koffsetright"}], "}"}], ",", 
          "deltaxpos", ",", "xyinset"}], "}"}], " ", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "4.5", ",", 
          RowBox[{"-", "1.5"}], ",", "1.5", ",", 
          RowBox[{"-", "2"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.", ",", 
            RowBox[{"-", "0.6"}]}], "}"}], ",", 
          RowBox[{"-", "0.1"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.6", ",", "1.1"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"f", " ", "=", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            FractionBox["1", "8"], " ", 
            SuperscriptBox["x", "4"]}], " ", "-", 
           SuperscriptBox["x", "2"], "+", "1"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "expf", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "xstart", ",", " ", "xstop", ",", "ystart", ",", "ystop", ",", " ", 
          "kchangesides", ",", 
          RowBox[{"{", 
           RowBox[{"koffsetleft", ",", "koffsetright"}], "}"}], ",", 
          "deltaxpos", ",", "xyinset"}], "}"}], " ", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.02"}], ",", "10", ",", 
          RowBox[{"-", "0.1"}], ",", "2.7", ",", "1.5", ",", 
          RowBox[{"{", 
           RowBox[{"1.75", ",", 
            RowBox[{"-", "0.8"}]}], "}"}], ",", 
          RowBox[{"-", "0.08"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.5", ",", "2.3"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"f", " ", "=", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", " ", 
          RowBox[{"3", "x", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "0.5"}], "x"}]]}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "logisticf", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "xstart", ",", " ", "xstop", ",", "ystart", ",", "ystop", ",", " ", 
          "kchangesides", ",", 
          RowBox[{"{", 
           RowBox[{"koffsetleft", ",", "koffsetright"}], "}"}], ",", 
          "deltaxpos", ",", "xyinset"}], "}"}], " ", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.02"}], ",", "8", ",", 
          RowBox[{"-", "0.35"}], ",", "2.22", ",", "1.5", ",", 
          RowBox[{"{", 
           RowBox[{"1.60", ",", 
            RowBox[{"-", "0.55"}]}], "}"}], ",", 
          RowBox[{"-", "0.1"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.4", ",", "2.0"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"f", " ", "=", 
        RowBox[{"Function", "[", 
         RowBox[{"x", ",", " ", 
          FractionBox["2", 
           RowBox[{"1", "+", 
            RowBox[{"61", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "1.1"}], "x"}]]}]}]]}], "]"}]}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"xaddlength", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"xstop", "-", "xstart"}], ")"}], "/", "10"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"secant", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"f", "[", "x1", "]"}], "-", 
           RowBox[{"f", "[", "x0", "]"}]}], 
          RowBox[{" ", "deltax"}]], "x"}], "+", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{
           RowBox[{"x1", " ", 
            RowBox[{"f", "[", "x0", "]"}]}], "-", 
           RowBox[{"x0", " ", 
            RowBox[{"f", "[", "x1", "]"}]}]}]}], "deltax"]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"m", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", "x1", "]"}], "-", 
       RowBox[{"f", "[", "x0", "]"}]}], 
      RowBox[{" ", "deltax"}]]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Lambda]", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"ystop", "-", "ystart"}], 
       RowBox[{"xstop", "-", "xstart"}]], " ", "/", 
      RowBox[{"(", 
       RowBox[{"1", "/", "GoldenRatio"}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xstart", ",", "xstop"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xstart", ",", "xstop"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ystart", ",", "ystop"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", " ", "600"}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<x \>\"", ",", "14", ",", "Italic"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<y\>\"", ",", "14", ",", "Italic"}], "]"}]}], "}"}]}], 
      ",", 
      RowBox[{"Background", "\[Rule]", " ", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0.972549", ",", " ", "0.937255", ",", " ", "0.694118"}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RGBColor", "[", 
          RowBox[{"0.378912", ",", " ", "0.742199", ",", " ", "0.570321"}], 
          "]"}], ",", 
         RowBox[{"Thickness", "[", ".005", "]"}]}], " ", "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "\[IndentingNewLine]", 
         RowBox[{"Arrowheads", "[", ".025", "]"}], ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xstop", "-", "0.02"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"xstop", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"ystop", "-", "0.02"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "ystop"}], "}"}]}], "}"}], "]"}], ",", "Red", 
         ",", 
         RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
         RowBox[{"Disk", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x0", ",", 
             RowBox[{"f", "[", "x0", "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"deltax", ">", "0.3"}], ",", "0.2", ",", "0.001"}], 
             "]"}], 
            RowBox[{"{", 
             RowBox[{"1", ",", "\[Lambda]"}], "}"}]}], ",", 
           RowBox[{"arctan", "[", 
            RowBox[{"m", ",", "\[Lambda]"}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "Black", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", " ", 
             RowBox[{"x0", ",", 
              RowBox[{"f", "[", "x0", "]"}]}], " ", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x1", ",", 
              RowBox[{"f", "[", "x0", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x1", ",", 
              RowBox[{"f", "[", "x1", "]"}]}], "}"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<\[CapitalDelta]x\>\"", ",", "14", ",", "Bold"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x0", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x1", "-", "x0"}], ")"}], "/", "2"}]}], ",", 
             RowBox[{
              RowBox[{"f", "[", "x0", " ", "]"}], "+", "deltaxpos"}]}], 
            "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<\[CapitalDelta]y\>\"", ",", "Medium"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x1", " ", "+", "0.2"}], ",", 
             RowBox[{
              RowBox[{"f", "[", "x0", " ", "]"}], " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"f", "[", "x1", "]"}], "-", 
                 RowBox[{"f", "[", "x0", "]"}]}], ")"}], "/", "2"}]}]}], 
            "}"}]}], "]"}], ",", "\[IndentingNewLine]", "Blue", ",", 
         RowBox[{"Thickness", "[", ".005", "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x0", " ", "-", "xaddlength"}], ",", 
              RowBox[{"secant", "[", 
               RowBox[{"x0", " ", "-", "xaddlength"}], "]"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", " ", "+", "xaddlength"}], ",", 
              RowBox[{"secant", "[", 
               RowBox[{"x1", " ", "+", "xaddlength"}], "]"}]}], "}"}]}], 
           "}"}], "]"}], ",", "\[IndentingNewLine]", "Red", ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"x0", ",", 
            RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"x1", ",", 
            RowBox[{"f", "[", "x1", "]"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<m\>\"", ",", "Italic"}], "]"}], ",", 
                "\"\< = \>\"", ",", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"deltax", ">", " ", "0.0001"}], ",", 
                  RowBox[{"ToString", "[", 
                   RowBox[{"NumberForm", "[", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"f", "[", "x1", "]"}], "-", 
                    RowBox[{"f", "[", "x0", "]"}]}], 
                    RowBox[{" ", "deltax"}]], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"Text", "[", "\"\<undefined\>\"", "]"}], ",", " ",
                     "Red", ",", "14"}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
             
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"x0", "<", "kchangesides"}], ",", 
               RowBox[{"{", " ", 
                RowBox[{
                 RowBox[{"x0", "+", "koffsetleft"}], ",", 
                 RowBox[{"f", "[", "x0", "]"}]}], " ", "}"}], ",", 
               RowBox[{"{", " ", 
                RowBox[{
                 RowBox[{"x0", "+", "koffsetright"}], ",", 
                 RowBox[{"f", "[", "x0", "]"}]}], " ", "}"}]}], "]"}]}], 
            "]"}], " ", ",", "14"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"HoldForm", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<f(x)\>\"", ",", "Italic"}], "]"}], " ", "=", 
                " ", "p"}], 
               StyleBox["]", "WarholOrange"]}], 
              StyleBox["//.", "WarholOrange"], 
              RowBox[{"{", 
               RowBox[{"p", "\[Rule]", " ", 
                RowBox[{"f", "[", "x", "]"}]}], "}"}]}], ",", " ", 
             "xyinset"}], "]"}], ",", " ", 
           RowBox[{"RGBColor", "[", 
            RowBox[{"0.378912", ",", " ", "0.742199", ",", " ", "0.570321"}], 
            "]"}], ",", "20"}], "]"}]}], "}"}]}]}], " ", "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"func", ",", "p2", ",", "\"\<functions\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "p2", "\[Rule]", 
        "\"\<- \!\(\*SuperscriptBox[\(x\), \(2\)]\) + 4 x + 5\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "p3", "\[Rule]", 
        "\"\< \!\(\*SuperscriptBox[\(x\), \(3\)]\)- 6 \
\!\(\*SuperscriptBox[\(x\), \(2\)]\)+ 5 x + 12\>\""}], ",", 
       RowBox[{
       "p4", "\[Rule]", 
        "\"\< \!\(\*FractionBox[SuperscriptBox[\(x\), \(4\)], \(\(8\)\(\\\ \)\
\)]\) - \!\(\*SuperscriptBox[\(x\), \(2\)]\) + 1\>\""}], ",", 
       RowBox[{
       "expf", "\[Rule]", 
        "\"\< 3 x \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-0.5\)\\\ \
x\)]\)\>\""}], ",", 
       RowBox[{
       "logisticf", "\[Rule]", 
        "\"\<\!\(\*FractionBox[\(2\), \(1\\\  + \\\ 61\\\ \*SuperscriptBox[\(\
\[ExponentialE]\), \(\(-1.1\)\\\ x\)]\)]\)\>\""}]}], "}"}]}], "}"}], ",", 
   "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", "1", ",", 
       SubscriptBox["x", "0"]}], "}"}], ",", 
     RowBox[{"Evaluate", "@", 
      RowBox[{"Switch", "[", 
       RowBox[{"func", ",", "p2", ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.1"}], ",", "4.9"}], "}"}]}], ",", "p3", ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.17"}], ",", "3.9"}], "}"}]}], ",", "p4", ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.8"}], ",", "2.8"}], "}"}]}], ",", "expf", ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"{", 
          RowBox[{".02", ",", "8.8"}], "}"}]}], ",", "logisticf", ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"{", 
          RowBox[{"0.01", ",", "7"}], "}"}]}]}], "]"}]}], ",", 
     RowBox[{"ControlType", "\[Rule]", "LabeledSlider"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"deltax", ",", "1", ",", "\[CapitalDelta]x"}], "}"}], ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "7"}]], ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", " ", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", "Manipulate"}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1", ",", "25"}], "}"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"HoldForm", "[", "m", "]"}], ",", 
       "\"\<, the average rate of change\>\""}], "}"}], "]"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.391354350125*^9, 3.391354377640625*^9}, {
   3.39151695778125*^9, 3.391516957984375*^9}, 3.391528270640625*^9, {
   3.39152845925*^9, 3.3915284711875*^9}, {3.391528547203125*^9, 
   3.39152855359375*^9}, 3.391528659234375*^9, 3.391528995796875*^9, 
   3.391529099171875*^9, {3.391537920645189*^9, 3.391537921826888*^9}, 
   3.3915387930496445`*^9, {3.391538824254515*^9, 3.391538856591013*^9}, 
   3.3920083003125*^9, 3.395543747671875*^9, {3.395669784359375*^9, 
   3.395669947640625*^9}, {3.39567000653125*^9, 3.395670023421875*^9}, {
   3.39567007159375*^9, 3.39567007925*^9}, {3.39567015809375*^9, 
   3.39567019609375*^9}, {3.395983748125*^9, 3.395983748484375*^9}, {
   3.395983794875*^9, 3.395983833328125*^9}, {3.3959838949375*^9, 
   3.395983908375*^9}, {3.39598394328125*^9, 3.395983959484375*^9}, {
   3.395984005328125*^9, 3.3959841239375*^9}, {3.395984159078125*^9, 
   3.395984218359375*^9}, {3.395984248453125*^9, 3.3959842963125*^9}, {
   3.395984365328125*^9, 3.3959847028125*^9}, 3.3959847685625*^9, {
   3.39598485140625*^9, 3.395984852125*^9}, 3.39598489603125*^9, {
   3.395990194703125*^9, 3.3959902285625*^9}, {3.395990277359375*^9, 
   3.395990293671875*^9}, {3.395990372125*^9, 3.395990413203125*^9}, 
   3.395990459984375*^9, {3.395990565296875*^9, 3.3959905894375*^9}, 
   3.395990836796875*^9, {3.39599089925*^9, 3.39599089996875*^9}, {
   3.395990937125*^9, 3.395990960890625*^9}, {3.395991097734375*^9, 
   3.395991104*^9}, {3.395991184421875*^9, 3.3959912246875*^9}, {
   3.395992625890625*^9, 3.39599262678125*^9}, {3.395992677625*^9, 
   3.3959926808125*^9}, 3.396087231671875*^9, {3.396087289890625*^9, 
   3.39608732575*^9}, {3.396087372125*^9, 3.396087402921875*^9}, {
   3.396087442328125*^9, 3.396087463125*^9}, 3.396087660890625*^9, {
   3.396087695828125*^9, 3.396087717609375*^9}, 3.39608775125*^9, {
   3.396087801375*^9, 3.396087801953125*^9}, 3.3960879190625*^9, {
   3.396087960390625*^9, 3.3960879633125*^9}, {3.39608799890625*^9, 
   3.396088001140625*^9}, {3.3960880701875*^9, 3.396088119609375*^9}, {
   3.396088232125*^9, 3.396088240125*^9}, {3.3960883125625*^9, 
   3.396088508109375*^9}, {3.396088546328125*^9, 3.396088571828125*^9}, {
   3.396088616171875*^9, 3.396088632765625*^9}, {3.396088699140625*^9, 
   3.396088717*^9}, {3.396088764890625*^9, 3.396088874046875*^9}, {
   3.396088915828125*^9, 3.396089025703125*^9}, {3.396089108265625*^9, 
   3.396089158953125*^9}, {3.3960893183125*^9, 3.396089404125*^9}, 
   3.396089453640625*^9, {3.396089496734375*^9, 3.396089801578125*^9}, {
   3.3960898768125*^9, 3.39608988265625*^9}, {3.39608992859375*^9, 
   3.396089949953125*^9}, {3.39609107346875*^9, 3.3960913404375*^9}, {
   3.396091396125*^9, 3.396091399015625*^9}, {3.39609155496875*^9, 
   3.39609173346875*^9}, {3.39609176415625*^9, 3.396091803484375*^9}, {
   3.396091836921875*^9, 3.396091893578125*^9}, {3.396091929703125*^9, 
   3.396091953671875*^9}, {3.396091990921875*^9, 3.396092049890625*^9}, {
   3.396092114671875*^9, 3.396092236546875*^9}, {3.39609226696875*^9, 
   3.39609226965625*^9}, {3.396092333125*^9, 3.396092398078125*^9}, {
   3.396092449296875*^9, 3.39609245178125*^9}, {3.39609259415625*^9, 
   3.396092618*^9}, {3.396092660890625*^9, 3.39609267034375*^9}, {
   3.39609270775*^9, 3.39609284653125*^9}, {3.39609289415625*^9, 
   3.396092982515625*^9}, {3.39609317678125*^9, 3.396093287125*^9}, {
   3.396093352359375*^9, 3.39609338578125*^9}, {3.396093422046875*^9, 
   3.396093429046875*^9}, {3.3960938758125*^9, 3.39609388578125*^9}, {
   3.396093931328125*^9, 3.396094002609375*^9}, {3.396101492875*^9, 
   3.39610154346875*^9}, 3.396101656703125*^9, {3.39610170159375*^9, 
   3.3961017101875*^9}, {3.39610174653125*^9, 3.39610179928125*^9}, {
   3.396101833890625*^9, 3.396101919953125*^9}, {3.39610200528125*^9, 
   3.396102005875*^9}, {3.396102053859375*^9, 3.396102090421875*^9}, {
   3.396102193609375*^9, 3.3961022264375*^9}, {3.396102278375*^9, 
   3.39610227846875*^9}, {3.396102325015625*^9, 3.39610237115625*^9}, {
   3.39610240934375*^9, 3.396102472828125*^9}, {3.3961025396875*^9, 
   3.396102612359375*^9}, {3.396102671671875*^9, 3.396102675796875*^9}, {
   3.396102712359375*^9, 3.3961027366875*^9}, {3.39617108896875*^9, 
   3.396171190140625*^9}, {3.396171397109375*^9, 3.396171460296875*^9}, {
   3.396171595828125*^9, 3.39617162246875*^9}, {3.396171657734375*^9, 
   3.39617170328125*^9}, {3.396171760953125*^9, 3.396171779671875*^9}, {
   3.396171837015625*^9, 3.396171841875*^9}, {3.39617188484375*^9, 
   3.396171886546875*^9}, {3.39617192675*^9, 3.3961719410625*^9}, {
   3.3961719906875*^9, 3.396171992265625*^9}, 3.396172061421875*^9, {
   3.396172182921875*^9, 3.39617218346875*^9}, {3.396172258640625*^9, 
   3.396172355140625*^9}, {3.3961725835*^9, 3.396172593046875*^9}, {
   3.396172663859375*^9, 3.396172681078125*^9}, 3.39617274490625*^9, 
   3.396172805*^9, {3.396172876890625*^9, 3.396173000640625*^9}, {
   3.396173059109375*^9, 3.396173059578125*^9}, {3.396173169671875*^9, 
   3.396173200328125*^9}, {3.396173246359375*^9, 3.396173306640625*^9}, {
   3.39617334846875*^9, 3.396173399484375*^9}, {3.396173454*^9, 
   3.396173456234375*^9}, {3.3961735645625*^9, 3.396173566265625*^9}, 
   3.396174073125*^9, {3.396174130265625*^9, 3.396174148390625*^9}, {
   3.396174254671875*^9, 3.396174269734375*^9}, 3.396174304234375*^9, {
   3.39617434165625*^9, 3.396174348671875*^9}, {3.3961743806875*^9, 
   3.396174408765625*^9}, {3.396174446671875*^9, 3.3961745155625*^9}, {
   3.39617457046875*^9, 3.396174620796875*^9}, {3.3961746956875*^9, 
   3.396174764296875*^9}, {3.396174851203125*^9, 3.396174852109375*^9}, {
   3.396174885140625*^9, 3.3961748871875*^9}, {3.39617502359375*^9, 
   3.3961750418125*^9}, {3.396175372578125*^9, 3.39617539890625*^9}, {
   3.396175429703125*^9, 3.396175467421875*^9}, {3.396175553328125*^9, 
   3.396175554640625*^9}, {3.3961760983125*^9, 3.396176116125*^9}, {
   3.396176376234375*^9, 3.396176384921875*^9}, {3.396323140625*^9, 
   3.396323185296875*^9}, {3.39632323665625*^9, 3.396323256296875*^9}, 
   3.3963233635625*^9, {3.396323428671875*^9, 3.396323435703125*^9}, 
   3.396323466375*^9, {3.396410927796875*^9, 3.396410952453125*^9}, {
   3.3964111343125*^9, 3.396411143546875*^9}, {3.396583215125*^9, 
   3.396583215734375*^9}, {3.39658331296875*^9, 3.3965833134375*^9}, {
   3.396798770625*^9, 3.39679878046875*^9}, {3.396802766049189*^9, 
   3.3968027661593475`*^9}, {3.396803340915807*^9, 3.396803347935901*^9}, {
   3.3968273585887575`*^9, 3.3968273851179695`*^9}, {3.396827456300002*^9, 
   3.3968274564718647`*^9}, {3.3968274952813835`*^9, 3.396827611772436*^9}, {
   3.3972366740432034`*^9, 3.397236810569518*^9}, 3.397404816859375*^9, {
   3.397404965734375*^9, 3.397405012140625*^9}, {3.397405332875*^9, 
   3.397405371859375*^9}, {3.397544797546875*^9, 3.39754480434375*^9}, {
   3.397544878671875*^9, 3.397544880734375*^9}, 3.397544930484375*^9, {
   3.39850503115625*^9, 3.39850503746875*^9}, {3.39850530175*^9, 
   3.398505309078125*^9}, {3.398514383992416*^9, 3.398514407554916*^9}, {
   3.398523271713616*^9, 3.398523276276116*^9}, {3.419704227458725*^9, 
   3.4197042281697474`*^9}},
 CellID->17037828]
}, Closed]],

Cell[CellGroupData[{

Cell["3*3 \:9b54\:65b9\:4ee3\:7801", "Section",
 CellChangeTimes->{{3.4071242585803328`*^9, 3.4071242729209538`*^9}, 
   3.419646936265472*^9},
 CellTags->"MagicSquare"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"toptheta", "=", "toptheta1"}], ",", 
       RowBox[{"righttheta", "=", "righttheta1"}], ",", 
       RowBox[{"lefttheta", "=", "lefttheta1"}], ",", 
       RowBox[{"bottomtheta", "=", "bottomtheta1"}], ",", 
       RowBox[{"fronttheta", "=", "fronttheta1"}], ",", 
       RowBox[{"backtheta", "=", "backtheta1"}], ",", 
       RowBox[{"fullverttheta", "=", "fullverttheta1"}], ",", 
       RowBox[{"fullhorztheta", "=", "fullhorztheta1"}], ",", 
       RowBox[{"fullrolltheta", "=", "fullrolltheta1"}], ",", 
       RowBox[{"shuff", "=", "shuff1"}], ",", 
       RowBox[{"reset", "=", "False"}], ",", 
       RowBox[{"diag1", "=", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"colorchoice", "=", "colorchoice1"}], ",", 
       RowBox[{"shapechoice", "=", "shapechoice1"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Refresh", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"controllist", "=", 
         RowBox[{"{", 
          RowBox[{
          "righttheta1", ",", "toptheta1", ",", "lefttheta1", ",", 
           "bottomtheta1", ",", "fronttheta1", ",", "backtheta1", ",", 
           "fullverttheta1", ",", "fullhorztheta1", ",", "fullrolltheta1"}], 
          "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"comparelist", "\[NotEqual]", "controllist"}], ",", 
          RowBox[{
           RowBox[{"active", "=", 
            RowBox[{"Part", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "right", ",", "top", ",", "left", ",", "bottom", ",", "front", 
                ",", "back", ",", "fullvert", ",", "fullhorz", ",", 
                "fullroll"}], "}"}], ",", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"Position", "[", 
                 RowBox[{
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"comparelist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "===", 
                    RowBox[{"controllist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", 
                    RowBox[{"Length", "[", "comparelist", "]"}]}], "}"}]}], 
                   "]"}], ",", "False"}], "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", " ", 
           RowBox[{"comparelist", "=", "controllist"}]}], ",", 
          RowBox[{"active", "=", "active"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Deploy", "[", "\[IndentingNewLine]", 
         RowBox[{"Column", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"LocatorPane", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", 
                    RowBox[{"diag1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"diag1", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ";", 
                    RowBox[{"fullrolltheta", "=", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", "Pi"}]}], ";", 
                    RowBox[{"active", "=", "fullroll"}]}], ")"}], "&"}], ",", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"diag1", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ";", 
                    RowBox[{"fullrolltheta", "=", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", "Pi"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"fullrolltheta", "==", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"fullrolltheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"frontside", ",", "fullrolltheta"}], "]"}], ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"frontbackmid", ",", "fullrolltheta"}], "]"}], 
                    ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"backside", ",", 
                    RowBox[{"-", "fullrolltheta"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fullrolltheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"diag1", "=", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], ";", 
                    RowBox[{"fullrolltheta", "=", "0"}]}], ")"}], "&"}]}], 
                    "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"Dynamic", "[", 
                    RowBox[{"Deploy", "[", 
                    RowBox[{"Graphics", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "0.2", "]"}], ",", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.85"}], "]"}], ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.45", ",", 
                    RowBox[{"-", "0.45"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.1"}], "]"}], ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.5"}], ",", "0.55"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.5", ",", 
                    RowBox[{"-", "0.45"}]}], "}"}]}], "}"}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Circle", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.55"}], ",", "0.5"}], "}"}], ",", "0.06", 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Pi", "/", "4"}], ",", 
                    RowBox[{"5", 
                    RowBox[{"Pi", "/", "4"}]}]}], "}"}]}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.9"}], "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.5"}], "]"}], "]"}], ",", 
                    RowBox[{"Rotate", "[", 
                    RowBox[{
                    RowBox[{"Rectangle", "[", 
                    RowBox[{
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.17"}], ",", 
                    RowBox[{"-", "0.3"}]}], "}"}]}], ",", 
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{"0.17", ",", "0.3"}], "}"}]}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "4"}]}], "]"}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Darker", "[", 
                    RowBox[{"Green", ",", "0.4"}], "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.5"}], "]"}], "]"}], ",", 
                    RowBox[{"Rotate", "[", 
                    RowBox[{
                    RowBox[{"Rectangle", "[", 
                    RowBox[{
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.17"}], ",", 
                    RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{"0.17", ",", 
                    RowBox[{"-", "0.3"}]}], "}"}]}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "4"}], ",", "diag1"}], "]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Darker", "[", 
                    RowBox[{"Green", ",", "0.4"}], "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.5"}], "]"}], "]"}], ",", 
                    RowBox[{"Rotate", "[", 
                    RowBox[{
                    RowBox[{"Rectangle", "[", 
                    RowBox[{
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.17"}], ",", "0.4"}], "}"}]}], ",", 
                    RowBox[{"diag1", "+", 
                    RowBox[{"{", 
                    RowBox[{"0.17", ",", "0.3"}], "}"}]}]}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "4"}], ",", "diag1"}], "]"}]}], 
                    "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
                    RowBox[{"ImagePadding", "\[Rule]", "13"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", "0.5"}], ",", 
                    RowBox[{"PlotRangeClipping", "\[Rule]", "False"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"75", "/", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "]"}], "]"}], 
                    "]"}], ",", 
                   RowBox[{"Appearance", "\[Rule]", 
                    RowBox[{"Style", "[", 
                    RowBox[{"None", ",", 
                    RowBox[{"Opacity", "[", "0", "]"}]}], "]"}]}]}], "]"}], 
                 ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"fullhorztheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fullhorztheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "fullhorz"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fullhorztheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"fullhorztheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"fullhorztheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"topside", ",", "fullhorztheta"}], "]"}], ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"topbottommid", ",", "fullhorztheta"}], "]"}], 
                    ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"bottomside", ",", "fullhorztheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fullhorztheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"fullhorztheta", "=", "0"}], ")"}], "&"}]}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "100"}]}], "]"}], ",", 
                   RowBox[{"labsty", "[", "\"\<full\>\"", "]"}], ",", "Top"}],
                   "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"toptheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"toptheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "top"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"toptheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"toptheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"toptheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"topside", ",", "toptheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"toptheta", "=", "0"}]}]}], "]"}]}], ")"}], "&"}],
                     ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"toptheta", "=", "0"}], ")"}], "&"}]}], "}"}]}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "100"}]}], "]"}], ",", 
                   RowBox[{"labsty", "[", "\"\<top\>\"", "]"}], ",", "Top"}], 
                  "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"Column", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Toggler", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "shuff", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"True", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<stop\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}], ",", 
                    RowBox[{"False", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<shuffle\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}]}], "}"}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Toggler", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "reset", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"True", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<reset\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}], ",", 
                    RowBox[{"False", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<reset\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}]}], "}"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]}], 
                "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"VerticalSlider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"fullverttheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fullverttheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "fullvert"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fullverttheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"fullverttheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"fullverttheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"leftside", ",", "fullverttheta"}], "]"}], ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"rightleftmid", ",", "fullverttheta"}], "]"}], 
                    ";", 
                    RowBox[{"move", "[", 
                    RowBox[{"rightside", ",", "fullverttheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fullverttheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"fullverttheta", "=", "0"}], ")"}], "&"}]}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "100"}], "}"}]}]}], "]"}], ",", 
                   
                   RowBox[{"labsty", "[", "\"\<full\>\"", "]"}], ",", 
                   "Left"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Dynamic", "[", 
                  RowBox[{
                   RowBox[{"shuffle", "[", 
                    RowBox[{"shuff", ",", "reset"}], "]"}], ";", 
                   RowBox[{"reset", "=", "False"}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Show", "[", 
                    RowBox[{
                    RowBox[{"Switch", "[", 
                    RowBox[{
                    "active", ",", "\[IndentingNewLine]", "right", ",", 
                    RowBox[{"{", 
                    RowBox[{"leftside", ",", "rightleftmid", ",", 
                    RowBox[{"rightsiderotate", "[", 
                    RowBox[{"rightside", ",", "righttheta"}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "top", ",", 
                    RowBox[{"{", 
                    RowBox[{"bottomside", ",", "topbottommid", ",", 
                    RowBox[{"topsiderotate", "[", 
                    RowBox[{"topside", ",", "toptheta"}], "]"}]}], "}"}], ",",
                     "\[IndentingNewLine]", "left", ",", 
                    RowBox[{"{", 
                    RowBox[{"rightside", ",", "rightleftmid", ",", 
                    RowBox[{"leftsiderotate", "[", 
                    RowBox[{"leftside", ",", "lefttheta"}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "bottom", ",", 
                    RowBox[{"{", 
                    RowBox[{"topside", ",", "topbottommid", ",", 
                    RowBox[{"bottomsiderotate", "[", 
                    RowBox[{"bottomside", ",", "bottomtheta"}], "]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", "front", ",", 
                    RowBox[{"{", 
                    RowBox[{"backside", ",", "frontbackmid", ",", 
                    RowBox[{"frontsiderotate", "[", 
                    RowBox[{"frontside", ",", "fronttheta"}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "back", ",", 
                    RowBox[{"{", 
                    RowBox[{"frontside", ",", "frontbackmid", ",", 
                    RowBox[{"backsiderotate", "[", 
                    RowBox[{"backside", ",", "backtheta"}], "]"}]}], "}"}], 
                    ",", "\[IndentingNewLine]", "fullvert", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"leftsiderotate", "[", 
                    RowBox[{"leftside", ",", "fullverttheta"}], "]"}], ",", 
                    RowBox[{"leftsiderotate", "[", 
                    RowBox[{"rightleftmid", ",", "fullverttheta"}], "]"}], 
                    ",", 
                    RowBox[{"rightsiderotate", "[", 
                    RowBox[{"rightside", ",", "fullverttheta"}], "]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", "fullhorz", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"topsiderotate", "[", 
                    RowBox[{"topside", ",", "fullhorztheta"}], "]"}], ",", 
                    RowBox[{"topsiderotate", "[", 
                    RowBox[{"topbottommid", ",", "fullhorztheta"}], "]"}], 
                    ",", 
                    RowBox[{"bottomsiderotate", "[", 
                    RowBox[{"bottomside", ",", "fullhorztheta"}], "]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", "fullroll", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"frontsiderotate", "[", 
                    RowBox[{"frontside", ",", "fullrolltheta"}], "]"}], ",", 
                    RowBox[{"frontsiderotate", "[", 
                    RowBox[{"frontbackmid", ",", "fullrolltheta"}], "]"}], 
                    ",", 
                    RowBox[{"backsiderotate", "[", 
                    RowBox[{"backside", ",", 
                    RowBox[{"-", "fullrolltheta"}]}], "]"}]}], "}"}], ",", 
                    "\[IndentingNewLine]", "active", ",", 
                    RowBox[{"{", 
                    RowBox[{"leftside", ",", "rightside"}], "}"}]}], "]"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"PlotRange", "\[Rule]", "2.2"}], ",", 
                    RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
                    RowBox[{"ViewPoint", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"3.5", ",", "2", ",", "1.5"}], "}"}]}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "225"}], ",", 
                    RowBox[{"Background", "\[Rule]", 
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.95"}], "]"}]}]}], "]"}]}], "]"}], 
                 ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 "SpanFromLeft", ",", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"VerticalSlider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"backtheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"backtheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "back"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"backtheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"backtheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"backtheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"backside", ",", "backtheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"backtheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"backtheta", "=", "0"}], ")"}], "&"}]}], "}"}]}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "100"}], "}"}]}]}], "]"}], ",", 
                   
                   RowBox[{"labsty", "[", "\"\<back\>\"", "]"}], ",", 
                   "Right"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"VerticalSlider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"lefttheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"lefttheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "left"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"lefttheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"lefttheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"lefttheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"leftside", ",", "lefttheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"lefttheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"lefttheta", "=", "0"}], ")"}], "&"}]}], "}"}]}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "100"}], "}"}]}]}], "]"}], ",", 
                   
                   RowBox[{"labsty", "[", "\"\<left\>\"", "]"}], ",", 
                   "Left"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", "SpanFromAbove", ",", "SpanFromBoth", 
                 ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"VerticalSlider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"righttheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"righttheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "right"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"righttheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"righttheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"righttheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"rightside", ",", "righttheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"righttheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"righttheta", "=", "0"}], ")"}], "&"}]}], "}"}]}],
                     "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "100"}], "}"}]}]}], "]"}], ",", 
                   
                   RowBox[{"labsty", "[", "\"\<right \>\"", "]"}], ",", 
                   "Right"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
               "\[IndentingNewLine]", "\[IndentingNewLine]", 
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Toggler", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", 
                    RowBox[{"shapechoice", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"shapechoice", "=", "#"}], ";", 
                    RowBox[{"shuff", "=", "False"}], ";", 
                    RowBox[{"shuff1", "=", "False"}], ";", 
                    RowBox[{"colorchoice", "=", "True"}], ";", 
                    RowBox[{"prep", "[", 
                    RowBox[{"True", ",", "True"}], "]"}], ";", 
                    RowBox[{"prep", "[", 
                    RowBox[{"#", ",", "colorchoice"}], "]"}], ";", 
                    RowBox[{"shapechoice1", "=", "#"}], ";", 
                    RowBox[{"colorchoice1", "=", "colorchoice"}]}], ")"}], 
                    "&"}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"True", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<spheres\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}], ",", 
                    RowBox[{"False", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<cubes\>\"", ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}]}], "}"}]}], 
                  "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"fronttheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fronttheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "front"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fronttheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"fronttheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"fronttheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"frontside", ",", "fronttheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fronttheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"fronttheta", "=", "0"}], ")"}], "&"}]}], "}"}]}],
                     "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "100"}]}], "]"}], ",", 
                   RowBox[{"labsty", "[", "\"\<front\>\"", "]"}], ",", 
                   "Bottom"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Labeled", "[", 
                  RowBox[{
                   RowBox[{"Slider", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"bottomtheta", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"bottomtheta", "=", "#"}], ";", 
                    RowBox[{"active", "=", "bottom"}]}], ")"}], "&"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"bottomtheta", "=", "#"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"bottomtheta", "\[Equal]", 
                    RowBox[{"Pi", "/", "2"}]}], "||", 
                    RowBox[{"bottomtheta", "\[Equal]", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"move", "[", 
                    RowBox[{"bottomside", ",", "bottomtheta"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"bottomtheta", "=", "0"}]}]}], "]"}]}], ")"}], 
                    "&"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"bottomtheta", "=", "0"}], ")"}], "&"}]}], 
                    "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
                    RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "100"}]}], "]"}], ",", 
                   RowBox[{"labsty", "[", "\"\<bottom\>\"", "]"}], ",", 
                   "Bottom"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Toggler", "[", 
                  RowBox[{
                   RowBox[{"Dynamic", "[", 
                    RowBox[{"colorchoice", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"colorchoice", "=", "#"}], ";", 
                    RowBox[{"shuff", "=", "False"}], ";", 
                    RowBox[{"shuff1", "=", "False"}], ";", 
                    RowBox[{"prep", "[", 
                    RowBox[{"shapechoice", ",", "#"}], "]"}], ";", 
                    RowBox[{"colorchoice1", "=", "#"}]}], ")"}], "&"}]}], 
                    "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"True", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    "shapechoice", ",", "\"\<glass\>\"", ",", 
                    "\"\<shiny\>\""}], "]"}], "]"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}], ",", 
                    RowBox[{"False", "\[Rule]", 
                    RowBox[{"Button", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    "shapechoice", ",", "\"\<solid\>\"", ",", 
                    "\"\<soft\>\""}], "]"}], "]"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"75", ",", "20"}], "}"}]}]}], "]"}]}]}], "}"}]}], 
                  "]"}]}], "}"}]}], "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "}"}], ",", 
             RowBox[{"Alignment", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Center", ",", "Center"}], "}"}]}], ",", 
             RowBox[{"Dividers", "\[Rule]", "None"}], ",", 
             RowBox[{"Background", "\[Rule]", 
              RowBox[{"Lighter", "[", 
               RowBox[{"Gray", ",", "0.95"}], "]"}]}]}], "]"}], 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], "]"}], 
         "]"}]}], ",", 
       RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{
         "righttheta", ",", "toptheta", ",", "lefttheta", ",", "bottomtheta", 
          ",", "fronttheta", ",", "backtheta", ",", "fullverttheta", ",", 
          "fullhorztheta", ",", "fullrolltheta", ",", "diag1", ",", "shuff", 
          ",", "reset", ",", "colorchoice", ",", "shapechoice"}], "}"}]}]}], 
      "]"}]}], "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"righttheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"toptheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lefttheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fronttheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"bottomtheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"backtheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fullverttheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fullhorztheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fullrolltheta1", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"shuff1", ",", "False"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"colorchoice1", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"shapechoice1", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
     "righttheta1", ",", "toptheta1", ",", "lefttheta1", ",", "bottomtheta1", 
      ",", "fronttheta1", ",", "backtheta1", ",", "fullverttheta1", ",", 
      "fullhorztheta1", ",", "fullrolltheta1", ",", "shuff1", ",", 
      "colorchoice1", ",", "shapechoice1", ",", "active"}], "}"}]}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"prep", "[", 
        RowBox[{"shpch_", ",", "colorchoice_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"tospheres", "[", "cube_", "]"}], ":=", 
           RowBox[{"Module", "[", 
            RowBox[{
             RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"makespheres", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "pt1_", ",", "pt2_", ",", "pt3_", ",", "pt4_", ",", "pt5_"}],
                  "}"}], "]"}], ":=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{"colorchoice", ",", 
                   RowBox[{"Specularity", "[", "0", "]"}], ",", 
                   RowBox[{"Specularity", "[", 
                    RowBox[{"White", ",", "40"}], "]"}]}], "]"}], ",", 
                 RowBox[{"Sphere", "[", 
                  RowBox[{
                   RowBox[{"Mean", "[", 
                    RowBox[{"{", 
                    RowBox[{"pt1", ",", "pt3"}], "}"}], "]"}], ",", "0.35"}], 
                  "]"}]}], "}"}]}], ";", 
              RowBox[{
               RowBox[{"Graphics3D", "[", 
                RowBox[{
                 RowBox[{"DeleteCases", "[", 
                  RowBox[{
                   RowBox[{"MapAt", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Apply", "[", 
                    RowBox[{"makespheres", ",", "#"}], "]"}], ")"}], "&"}], 
                    ",", 
                    RowBox[{"cube", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"i", ",", "2"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "2", ",", "7"}], "}"}]}], "]"}]}], 
                    "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", "_"}], "}"}]}],
                   "]"}], ",", 
                 RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
                 RowBox[{"Lighting", "\[Rule]", "Automatic"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "2"}]}], "]"}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"GrayLevel", "[", "1", "]"}], "\[Rule]", 
                  RowBox[{"GrayLevel", "[", "0.75", "]"}]}], ",", 
                 RowBox[{"Glow", "\[Rule]", "Identity"}]}], "}"}]}]}]}], 
            "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"unitcube", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x0_", ",", "y0_", ",", "z0_"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
              "clr1_", ",", "clr2_", ",", "clr3_", ",", "clr4_", ",", "clr5_",
                ",", "clr6_"}], "}"}], ",", "edgecolor_"}], "]"}], ":=", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", "shpch"}], ",", "tospheres", ",", "Identity"}], 
             "]"}], "[", "\[IndentingNewLine]", 
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"EdgeForm", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
                    "edgecolor"}], "}"}], "]"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr1", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr2", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr3", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr4", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr5", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "+", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"clr6", ",", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "+", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "0.5"}], ",", 
                    RowBox[{"y0", "-", "0.5"}], ",", 
                    RowBox[{"z0", "-", "0.5"}]}], "}"}]}], "}"}], "]"}]}], 
                 "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
              RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
              RowBox[{"Lighting", "\[Rule]", "None"}]}], "]"}], 
            "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"rotatecube", "[", 
            RowBox[{"thecube_", ",", "angle_", ",", "vector_", ",", "pt_"}], 
            "]"}], ":=", 
           RowBox[{"MapAt", "[", 
            RowBox[{
             RowBox[{"RotationTransform", "[", 
              RowBox[{"angle", ",", "vector", ",", "pt"}], "]"}], ",", 
             "thecube", ",", 
             RowBox[{"If", "[", 
              RowBox[{"shpch", ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", "i", ",", "2", ",", "1"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "2", ",", "7"}], "}"}]}], "]"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", "i", ",", "2", ",", "2", ",", "1"}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "2", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"thecube", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}],
               "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{"shpch", ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "frontclr", ",", "backclr", ",", "topclr", ",", "bottomclr", 
               ",", "rightclr", ",", "leftclr", ",", "intclr", ",", 
               "edgeclr"}], "}"}], "=", "\[IndentingNewLine]", 
             RowBox[{"Switch", "[", 
              RowBox[{"colorchoice", ",", "True", " ", 
               RowBox[{"(*", "classic", "*)"}], ",", 
               RowBox[{"MapAt", "[", 
                RowBox[{"Glow", ",", 
                 RowBox[{"{", 
                  RowBox[{"Red", ",", 
                   RowBox[{"Lighter", "[", 
                    RowBox[{"Orange", ",", "0.2"}], "]"}], ",", 
                   RowBox[{"Darker", "[", 
                    RowBox[{"Green", ",", "0.3"}], "]"}], ",", "Blue", ",", 
                   "White", ",", "Yellow", ",", "Black", ",", "Black"}], 
                  "}"}], ",", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", "i", "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
                "]"}], ",", "False", " ", 
               RowBox[{"(*", "glass", "*)"}], ",", "\[IndentingNewLine]", 
               RowBox[{"MapAt", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"Directive", "@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Glow", "[", "#", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75", "]"}]}], "}"}]}], ")"}], 
                  "&"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"Red", ",", "Orange", ",", 
                   RowBox[{"Darker", "[", 
                    RowBox[{"Green", ",", "0.3"}], "]"}], ",", "Blue", ",", 
                   RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", "0.5"}], "]"}], ",", "Yellow", ",", 
                   RowBox[{"Directive", "@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Glow", "[", "White", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0", "]"}]}], "}"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"White", ",", "Thin"}], "}"}]}], "}"}], ",", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", "i", "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
                "]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
           "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"clrlst", "=", 
           RowBox[{"Table", "[", 
            RowBox[{"intclr", ",", 
             RowBox[{"{", "6", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"c", "[", 
            RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "]"}], ":=", 
           RowBox[{"unitcube", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], ",", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{"clrlst", ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p1", "\[Equal]", "1"}], ",", 
                   RowBox[{"1", "\[Rule]", "frontclr"}], ",", 
                   RowBox[{"1", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p1", "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", 
                   RowBox[{"2", "\[Rule]", "backclr"}], ",", 
                   RowBox[{"2", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p2", "\[Equal]", "1"}], ",", 
                   RowBox[{"3", "\[Rule]", "rightclr"}], ",", 
                   RowBox[{"3", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p2", "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", 
                   RowBox[{"4", "\[Rule]", "leftclr"}], ",", 
                   RowBox[{"4", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "4", "]"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p3", "\[Equal]", "1"}], ",", 
                   RowBox[{"5", "\[Rule]", "topclr"}], ",", 
                   RowBox[{"5", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "5", "]"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"p3", "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", 
                   RowBox[{"6", "\[Rule]", "bottomclr"}], ",", 
                   RowBox[{"6", "\[Rule]", 
                    RowBox[{"clrlst", "[", 
                    RowBox[{"[", "6", "]"}], "]"}]}]}], "]"}]}], "}"}]}], 
              "]"}], ",", "edgeclr"}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"clractive", "=", "colorchoice"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"clrcomp", "\[NotEqual]", "clractive"}], ",", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{"start", "[", "]"}], "]"}], ";", 
             RowBox[{"clrcomp", "=", "clractive"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"shpactive", "=", "shpch"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"shpcomp", "\[NotEqual]", "shpactive"}], ",", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{"start", "[", "]"}], "]"}], ";", 
             RowBox[{"shpcomp", "=", "shpactive"}]}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"prep", "[", 
       RowBox[{"True", ",", "True"}], "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"clrcomp", "=", "False"}], ";", "\[IndentingNewLine]", 
      RowBox[{"clractive", "=", "True"}], ";", "\[IndentingNewLine]", 
      RowBox[{"shpcomp", "=", "False"}], ";", "\[IndentingNewLine]", 
      RowBox[{"shpactive", "=", "True"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rightsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"leftsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"topsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bottomsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"frontsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"backsiderotate", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"rotatecube", "[", 
            RowBox[{"#", ",", "angle", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ")"}], "&"}],
          ",", "cubelist"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cycle", "[", "angle_", "]"}], ":=", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"angle", "\[Equal]", 
          RowBox[{"Pi", "/", "2"}]}], ",", "RotateRight", ",", 
         RowBox[{"angle", "\[Equal]", 
          RowBox[{
           RowBox[{"-", "Pi"}], "/", "2"}]}], ",", "RotateLeft", ",", "True", 
         ",", "Identity"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cycle1", "[", 
        RowBox[{"alist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"cycle", "[", "angle", "]"}], "[", 
          RowBox[{
           RowBox[{"cycle", "[", "angle", "]"}], "[", 
           RowBox[{"Take", "[", 
            RowBox[{"alist", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "8"}], "}"}]}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"Last", "[", "alist", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"labsty", "[", "str_", "]"}], ":=", 
       RowBox[{"Style", "[", 
        RowBox[{"str", ",", " ", "\"\<Label\>\"", ",", " ", 
         RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"start", "[", "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"rightside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "0"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "0"}], "]"}]}], "}"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}], ",", "0"}], "]"}], ",", 
             RowBox[{"c", "[", 
              RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ";"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"start", "[", "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"move", "[", 
        RowBox[{"cubelist_", ",", "angle_"}], "]"}], ":=", 
       RowBox[{"Switch", "[", 
        RowBox[{
        "cubelist", ",", "\[IndentingNewLine]", "rightside", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"rightside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"rightsiderotate", "[", 
              RowBox[{"rightside", ",", "angle"}], "]"}], ",", 
             RowBox[{"-", "angle"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"rightside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "leftside", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"leftside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"leftsiderotate", "[", 
              RowBox[{"leftside", ",", "angle"}], "]"}], ",", 
             RowBox[{"-", "angle"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"leftside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "rightleftmid", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"rightleftmid", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"rightsiderotate", "[", 
              RowBox[{"rightleftmid", ",", "angle"}], "]"}], ",", 
             RowBox[{"-", "angle"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"rightleftmid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "topside", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"topside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"topsiderotate", "[", 
              RowBox[{"topside", ",", "angle"}], "]"}], ",", "angle"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"topside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "bottomside", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"bottomside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"bottomsiderotate", "[", 
              RowBox[{"bottomside", ",", "angle"}], "]"}], ",", "angle"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"bottomside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "topbottommid", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"topbottommid", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"topsiderotate", "[", 
              RowBox[{"topbottommid", ",", "angle"}], "]"}], ",", "angle"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"backside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"backside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"frontbackmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"frontbackmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"8", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"topbottommid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "frontside", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"frontside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"frontsiderotate", "[", 
              RowBox[{"frontside", ",", "angle"}], "]"}], ",", 
             RowBox[{"-", "angle"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"3", "\[Rule]", 
                RowBox[{"frontside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "backside", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"backside", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"backsiderotate", "[", 
              RowBox[{"backside", ",", "angle"}], "]"}], ",", "angle"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"3", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"4", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"5", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"7", "\[Rule]", 
                RowBox[{"backside", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", "frontbackmid", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"frontbackmid", "=", 
           RowBox[{"cycle1", "[", 
            RowBox[{
             RowBox[{"frontsiderotate", "[", 
              RowBox[{"frontbackmid", ",", "angle"}], "]"}], ",", 
             RowBox[{"-", "angle"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"rightside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"leftside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"rightleftmid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"rightleftmid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"6", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"4", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "5", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "6", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"bottomside", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"bottomside", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"4", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"topbottommid", "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{"topbottommid", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"4", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], ",", 
               RowBox[{"9", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "9", "]"}], "]"}]}], ",", 
               RowBox[{"8", "\[Rule]", 
                RowBox[{"frontbackmid", "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"actionlist", "=", 
       RowBox[{"Defer", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"move", "[", 
           RowBox[{"rightside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"rightside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"leftside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"leftside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"rightleftmid", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"rightleftmid", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"topside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"topside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"bottomside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"bottomside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"topbottommid", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"topbottommid", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"frontside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"frontside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"backside", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"backside", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"frontbackmid", ",", 
            RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
          RowBox[{"move", "[", 
           RowBox[{"frontbackmid", ",", 
            RowBox[{
             RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"shuffle", "[", 
        RowBox[{"shuff_", ",", "reset_"}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{"reset", ",", 
         RowBox[{"start", "[", "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{"shuff", ",", 
           RowBox[{
            RowBox[{"dolist", "=", 
             RowBox[{"RandomChoice", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", "18"}], "]"}], ",", "1"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"actionlist", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "#"}], "]"}], "]"}], ")"}], "&"}], ",", 
              "dolist"}], "]"}]}]}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"comparelist", "=", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"Pi", "/", "2"}], ",", "0", ",", "0", ",", "0", ",", "0", 
         ",", "0", ",", "0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"active", "=", "right"}], ";"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "}"}]}], ",", 
   RowBox[{"ControllerLinking", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.35757176568782*^9, 3.36353346850584*^9, 3.36353591377196*^9, 
   3.36354584989177*^9, 3.36354753345261*^9, {3.36354917324051*^9, 
   3.3635491938902*^9}, 3.36369758082119*^9, {3.36369812147861*^9, 
   3.36369812263027*^9}, 3.36371087750087*^9, 3.36925495993304*^9, {
   3.3701251886967535`*^9, 3.3701251902990575`*^9}, 3.373830637088591*^9, {
   3.374871067876071*^9, 3.374871070397196*^9}, {3.3829092430852847`*^9, 
   3.3829093349751444`*^9}, 3.38531873558648*^9, {3.3853187728300333`*^9, 
   3.385318776445232*^9}, {3.3878086027104588`*^9, 3.3878086042388372`*^9}, {
   3.4068512320368605`*^9, 3.406851232287221*^9}, 3.4071242729209538`*^9},
 CellID->1496021318]
}, Closed]]
},
WindowSize->{615, 559},
WindowMargins->{{72, Automatic}, {34, Automatic}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 27, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Bouncing ball"->{
  Cell[590, 23, 157, 3, 71, "Section",
   CellTags->"Bouncing ball"],
  Cell[750, 28, 428, 13, 72, "Input",
   CellTags->"Bouncing ball"],
  Cell[1181, 43, 222, 5, 59, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[1406, 50, 4362, 114, 332, "Input",
   CellTags->"Bouncing ball"],
  Cell[5771, 166, 259, 5, 59, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[6033, 173, 2654, 77, 292, "Input",
   CellTags->"Bouncing ball"],
  Cell[8690, 252, 185, 4, 59, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[8878, 258, 159, 3, 31, "Input",
   CellTags->"Bouncing ball"],
  Cell[15364, 419, 404, 9, 31, "Input",
   CellTags->"Bouncing ball"]},
 "Deviation"->{
  Cell[15805, 433, 153, 2, 41, "Section",
   CellTags->"Deviation"]},
 "MagicSquare"->{
  Cell[41727, 1028, 169, 3, 41, "Section",
   CellTags->"MagicSquare"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Bouncing ball", 167603, 3912},
 {"Deviation", 168273, 3931},
 {"MagicSquare", 168361, 3934}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 157, 3, 71, "Section",
 CellTags->"Bouncing ball"],
Cell[750, 28, 428, 13, 72, "Input",
 CellTags->"Bouncing ball"],
Cell[1181, 43, 222, 5, 59, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[1406, 50, 4362, 114, 332, "Input",
 CellTags->"Bouncing ball"],
Cell[5771, 166, 259, 5, 59, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[6033, 173, 2654, 77, 292, "Input",
 CellTags->"Bouncing ball"],
Cell[8690, 252, 185, 4, 59, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[8878, 258, 159, 3, 31, "Input",
 CellTags->"Bouncing ball"],
Cell[9040, 263, 6321, 154, 582, "Input"],
Cell[15364, 419, 404, 9, 31, "Input",
 CellTags->"Bouncing ball"]
}, Closed]],
Cell[CellGroupData[{
Cell[15805, 433, 153, 2, 41, "Section",
 CellTags->"Deviation"],
Cell[15961, 437, 25729, 586, 1645, "Input",
 CellID->17037828]
}, Closed]],
Cell[CellGroupData[{
Cell[41727, 1028, 169, 3, 41, "Section",
 CellTags->"MagicSquare"],
Cell[41899, 1033, 125391, 2866, 10072, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1496021318]
}, Closed]]
}
]
*)

(* End of internal cache information *)
